==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchSubFilterMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterListenerMatchSubFilterMatchBuilder extends EnvoyFilterListenerMatchSubFilterMatchFluentImpl<EnvoyFilterListenerMatchSubFilterMatchBuilder> implements VisitableBuilder<EnvoyFilterListenerMatchSubFilterMatch,EnvoyFilterListenerMatchSubFilterMatchBuilder>{
  public EnvoyFilterListenerMatchSubFilterMatchBuilder() {
    this(false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterListenerMatchSubFilterMatch(), validationEnabled);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterListenerMatchSubFilterMatch(), validationEnabled);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent,EnvoyFilterListenerMatchSubFilterMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent,EnvoyFilterListenerMatchSubFilterMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterListenerMatchSubFilterMatch build() {
    EnvoyFilterListenerMatchSubFilterMatch buildable = new EnvoyFilterListenerMatchSubFilterMatch(fluent.getName());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchSubFilterMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterListenerMatchSubFilterMatchBuilder extends EnvoyFilterListenerMatchSubFilterMatchFluent<EnvoyFilterListenerMatchSubFilterMatchBuilder> implements VisitableBuilder<EnvoyFilterListenerMatchSubFilterMatch,EnvoyFilterListenerMatchSubFilterMatchBuilder>{
  public EnvoyFilterListenerMatchSubFilterMatchBuilder() {
    this(false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterListenerMatchSubFilterMatch(), validationEnabled);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterListenerMatchSubFilterMatch(), validationEnabled);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent,EnvoyFilterListenerMatchSubFilterMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent,EnvoyFilterListenerMatchSubFilterMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterListenerMatchSubFilterMatch());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterListenerMatchSubFilterMatchBuilder(EnvoyFilterListenerMatchSubFilterMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterListenerMatchSubFilterMatch());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterListenerMatchSubFilterMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterListenerMatchSubFilterMatch build() {
    EnvoyFilterListenerMatchSubFilterMatch buildable = new EnvoyFilterListenerMatchSubFilterMatch(fluent.getName());
    return buildable;
  }
  
}
